import React, { useState } from 'react';
import { X, ArrowLeft, ArrowRight } from 'lucide-react';
import BasicDetailsStep from './BasicDetails';
import LocationDetailsStep from './LandDetails';
import LandDetailsStep from './LocationDetails';
import AddAmenitiesPrice from './AmenitiesDetails';
import UploadPage from './AddPhotos';

// Developer section imports remain the same
import DeveloperProjectDetails from './developer-properties/DeveloperProjectDetails';
import DeveloperAmenitiesPriceStep from './developer-properties/DeveloperAmenitiesPriceStep';
import DeveloperLocationDetailsStep from './developer-properties/DeveloperLocationDetailsStep';
import DeveloperUploadPage from './developer-properties/DeveloperUploadPage';

import axios from '@/services/APIservices';

const PropertyWizardModal = ({ isOpen, onClose, userId }) => {
  const [activeStep, setActiveStep] = useState(1);
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [error, setError] = useState(null);

  const [mainFile, setMainFile] = useState(null);

  // States for form data
  const [intent, setIntent] = useState('Sell');
  const [role, setRole] = useState('');
  const [propertyType, setPropertyType] = useState('');
  const [sizeUnit, setSizeUnit] = useState('SQ Yard');
  const [size, setSize] = useState('');
  const [length, setLength] = useState('');
  const [breadth, setBreadth] = useState('');
  const [roadTouch, setRoadTouch] = useState('');
  const [plotFacing, setPlotFacing] = useState('');
  const [distanceFromAirport, setDistanceFromAirport] = useState('');
  const [distanceFromRailway, setDistanceFromRailway] = useState('');
  const [distanceFromBusStand, setDistanceFromBusStand] = useState('');
  const [distanceFromHospital, setDistanceFromHospital] = useState('');
  const [distanceFromSchool, setDistanceFromSchool] = useState('');
  const [city, setCity] = useState('');
  const [locality, setLocality] = useState('');
  const [subLocality, setSubLocality] = useState('');
  const [detailedAddress, setDetailedAddress] = useState('');
  const [expectedPrice, setExpectedPrice] = useState('');
  const [priceUnit, setPriceUnit] = useState('');
  const [photos, setPhotos] = useState([]);
  const [youTubeLink, setYouTubeLink] = useState('');
  const [droneViewLink, setDroneViewLink] = useState('');

  const [basicRequirements, setBasicRequirements] = useState({
    water: false,
    electricity: false,
    roadAccess: false,
    boundaryWall: false,
    gatedCommunity: false
  });




    // Add these new state variables near the top with other state declaration

const [projectExpectedPrice, setProjectExpectedPrice] = useState('');
const [projectPriceUnit, setProjectPriceUnit] = useState('');
/*const [projectBasicRequirements, setProjectBasicRequirements] = useState({
  water: false,
  electricity: false,
  roadAccess: false,
  boundaryWall: false,
  gatedCommunity: false
});*/
const [projectCity, setProjectCity] = useState('');
const [projectLocality, setProjectLocality] = useState('');
const [projectSubLocality, setProjectSubLocality] = useState('');
const [projectAddress, setProjectAddress] = useState('');
const [projectPhotos, setProjectPhotos] = useState([]);
const [projectYouTubeLink, setProjectYouTubeLink] = useState('');
const [projectDroneViewLink, setProjectDroneViewLink] = useState('');
const [projectMainImage, setProjectMainImage] = useState(null);
const [projectName, setProjectName] = useState('');
const [reraNo, setReraNo] = useState('');
const [projectLandType, setProjectLandType] = useState('');
const [projectDescription, setProjectDescription] = useState('');
const [projectAmenities, setProjectAmenities] = useState({});
const [projectPlotDetails, setProjectPlotDetails] = useState({
  plotNumber: '',
  plotSize: '',
  plotSizeUnit: ''
});


  const [submittedData, setSubmittedData] = useState(null);

  // Default steps for non-Developer roles
  const defaultSteps = [
    { number: 1, title: 'Basic & Size Details' },
    { number: 2, title: 'Location Details' },
    { number: 3, title: 'Land Details' },
    { number: 4, title: 'Amenities' },
    { number: 5, title: 'Video And Photo' },
  ];

  const developerSteps = [
    { number: 1, title: 'Project Details' },
    { number: 2, title: 'Amenities & Price' },
    { number: 3, title: 'Location Details' },
    { number: 4, title: 'Video And Photo' }
  ];

  // Dynamically select steps based on role
  const steps = role === 'Developer' ? developerSteps : defaultSteps;

  if (!isOpen) return null;

  const handleNext = () => {
    // Ensure we don't exceed the maximum steps for the current role
    setActiveStep((prev) => Math.min(prev + 1, steps.length));
  };

  const handlePrevious = () => {
    setActiveStep((prev) => Math.max(prev - 1, 1));
  };



  const handlePostAsAdmin = async () => { 
    setIsSubmitting(true);
    setError(null);




    try {
      const formData = new FormData();

    if (role === 'Developer') {




              // Project Name Validation
              if (!projectName.trim()) {
                throw new Error('Project Name is required');
              }
      
              // RERA Number Validation
              if (!reraNo.trim()) {
                throw new Error('RERA Number is required');
              }
      
              // Project Land Type Validation
              if (!projectLandType.trim()) {
                throw new Error('Project Land Type is required');
              }
      
              // Price Validation
              if (!projectExpectedPrice.trim()) {
                throw new Error('Expected Price is required');
              }
      
              // Price Unit Validation
              if (!projectPriceUnit.trim()) {
                throw new Error('Price Unit is required');
              }
      
              // Location Validation
              if (!projectCity.trim()) {
                throw new Error('City is required');
              }
      
              // Photos Validation
              if (!projectMainImage) {
                throw new Error('Main Project Image is required');
              }
      
              if (projectPhotos.length === 0) {
                throw new Error('At least one project photo is required');
              }

              



      // Developer-specific fields with unique names
      formData.append('dev_project_name', projectName);
      formData.append('dev_rera_no', reraNo);
      formData.append('dev_project_land_type', projectLandType);
      formData.append('dev_project_description', projectDescription);
      formData.append('dev_expected_price', projectExpectedPrice);
      formData.append('dev_price_unit', projectPriceUnit);
      //formData.append('dev_basic_requirements', JSON.stringify(projectBasicRequirements));
      formData.append('dev_city', projectCity);
      formData.append('dev_locality', projectLocality);
      formData.append('dev_sub_locality', projectSubLocality);
      formData.append('dev_address', projectAddress);
      formData.append('dev_youtube_link', projectYouTubeLink);
      formData.append('dev_drone_view_link', projectDroneViewLink);

      // Developer photos
      projectPhotos.forEach((photo, index) => {
        formData.append(`dev_photos[${index}]`, photo);
      });
      
      if (projectMainImage) {
        formData.append('dev_main_image', projectMainImage);
      }

      // Developer amenities and plot details
      formData.append('dev_amenities', JSON.stringify(projectAmenities));
      formData.append('dev_plot_details', JSON.stringify(projectPlotDetails));

    } else {

            // Existing landowner/agent fields 
            formData.append('intent', intent);
            formData.append('propertyType', propertyType);
            formData.append('sizeUnit', sizeUnit);
            formData.append('size', size);
            formData.append('length', length);
            formData.append('breadth', breadth);
            formData.append('roadTouch', roadTouch);
            formData.append('plotFacing', plotFacing);
            formData.append('distanceFromAirport', distanceFromAirport);
            formData.append('distanceFromRailway', distanceFromRailway);
            formData.append('distanceFromBusStand', distanceFromBusStand);
            formData.append('distanceFromHospital', distanceFromHospital);
            formData.append('distanceFromSchool', distanceFromSchool);
            formData.append('city', city);
            formData.append('locality', locality);
            formData.append('subLocality', subLocality);
            formData.append('detailedAddress', detailedAddress);
            formData.append('expectedPrice', expectedPrice);
            formData.append('priceUnit', priceUnit);
            formData.append('basicRequirements', JSON.stringify(basicRequirements));
            formData.append('youTubeLink', youTubeLink);
            formData.append('droneViewLink', droneViewLink);
      
            if (mainFile) {
              formData.append('mainFile', mainFile);
            }
      
            photos.forEach((photo, index) => {
              formData.append(`photos[${index}]`, photo);
            });
          }

    // Common fields for all roles
    formData.append('role', role);


      // Send request to Laravel API with user_id
      const response = await axios.post(
        role === 'Developer' 
          ? `api/developer-post-properties/${userId}` 
          : `api/user-post-properties/${userId}`, 
        formData, 
        {
          headers: {
            'Content-Type': 'multipart/form-data',
          },
          withCredentials: true
        }
      );


      // Store the submitted data in state
      setSubmittedData(response.data);
      console.log('Property posted successfully:', response.data);
      // Close the modal after successful submission
      onClose();
      window.location.reload();
    } catch (error) {
      console.error('Error posting property:', error);
      //setError(error.response?.data?.message || 'Failed to post property. Please try again.');

            // Detailed error handling
            if (error.response) {
              // The request was made and the server responded with a status code
              // that falls out of the range of 2xx
              const errorMessage = error.response.data.message || 
                                   error.response.data.error || 
                                   'Failed to post property. Please try again.';
              
              setError(errorMessage);
              
              // Optional: Log specific error details
              console.error('Server Error Details:', error.response.data);
            } else if (error.request) {
              // The request was made but no response was received
              setError('No response received from server. Please check your internet connection.');
            } else {
              // Something happened in setting up the request that triggered an Error
              setError(error.message || 'An unexpected error occurred. Please try again.');
            }      

    } finally {
      setIsSubmitting(false);
    }
  };


  const renderStepContent = () => {
    if (role === 'Developer') {
      // Developer-specific step content
      switch (activeStep) {
        case 1:
          return (
            <DeveloperProjectDetails 
            projectName={projectName}
            setProjectName={setProjectName}
            reraNo={reraNo}
            setReraNo={setReraNo}
            projectLandType={projectLandType}
            setProjectLandType={setProjectLandType}
            projectDescription={projectDescription}
            setProjectDescription={setProjectDescription}
          />
                );
        case 2:
          return (
        <DeveloperAmenitiesPriceStep
          projectExpectedPrice={projectExpectedPrice}
          setProjectExpectedPrice={setProjectExpectedPrice}
          projectPriceUnit={projectPriceUnit}
          setProjectPriceUnit={setProjectPriceUnit}
          //projectBasicRequirements={projectBasicRequirements}
          //setProjectBasicRequirements={setProjectBasicRequirements}
          projectAmenities={projectAmenities}
          setProjectAmenities={setProjectAmenities}
          projectPlotDetails={projectPlotDetails}
          setProjectPlotDetails={setProjectPlotDetails}
        
           />
          );
        case 3:
          return (
        <DeveloperLocationDetailsStep
          projectCity={projectCity}
          setProjectCity={setProjectCity}
          projectLocality={projectLocality}
          setProjectLocality={setProjectLocality}
          projectSubLocality={projectSubLocality}
          setProjectSubLocality={setProjectSubLocality}
          projectAddress={projectAddress}
          setProjectAddress={setProjectAddress}
           />
          );
        case 4:
          return (
       <DeveloperUploadPage
        projectPhotos={projectPhotos}
        setProjectPhotos={setProjectPhotos}
        projectYouTubeLink={projectYouTubeLink}
        setProjectYouTubeLink={setProjectYouTubeLink}
        projectDroneViewLink={projectDroneViewLink}
        setProjectDroneViewLink={setProjectDroneViewLink}
        projectMainImage={projectMainImage}
        setProjectMainImage={setProjectMainImage}
          />          
        );
        default:
          return null;
      }
    } else {
      // Non-developer step content
      switch (activeStep) {
        case 1:
          return (
            <BasicDetailsStep
              intent={intent}
              setIntent={setIntent}
              role={role}
              setRole={setRole}
              propertyType={propertyType}
              setPropertyType={setPropertyType}
              sizeUnit={sizeUnit}
              setSizeUnit={setSizeUnit}
              size={size}
              setSize={setSize}
              length={length}
              setLength={setLength}
              breadth={breadth}
              setBreadth={setBreadth}
            />
          );
        case 2:
          return (
            <LocationDetailsStep
              roadTouch={roadTouch}
              setRoadTouch={setRoadTouch}
              plotFacing={plotFacing}
              setPlotFacing={setPlotFacing}
              distanceFromAirport={distanceFromAirport}
              setDistanceFromAirport={setDistanceFromAirport}
              distanceFromRailway={distanceFromRailway}
              setDistanceFromRailway={setDistanceFromRailway}
              distanceFromBusStand={distanceFromBusStand}
              setDistanceFromBusStand={setDistanceFromBusStand}
              distanceFromHospital={distanceFromHospital}
              setDistanceFromHospital={setDistanceFromHospital}
              distanceFromSchool={distanceFromSchool}
              setDistanceFromSchool={setDistanceFromSchool}
            />
          );
        case 3:
          return (
            <LandDetailsStep
              city={city}
              setCity={setCity}
              locality={locality}
              setLocality={setLocality}
              subLocality={subLocality}
              setSubLocality={setSubLocality}
              detailedAddress={detailedAddress}
              setDetailedAddress={setDetailedAddress}
            />
          );
        case 4:
          return (
            <AddAmenitiesPrice
              expectedPrice={expectedPrice}
              setExpectedPrice={setExpectedPrice}
              priceUnit={priceUnit}
              setPriceUnit={setPriceUnit}
              basicRequirements={basicRequirements}
              setBasicRequirements={setBasicRequirements}
            />
          );
        case 5:
          return (
            <UploadPage
              photos={photos}
              setPhotos={setPhotos}
              youTubeLink={youTubeLink}
              setYouTubeLink={setYouTubeLink}
              droneViewLink={droneViewLink}
              setDroneViewLink={setDroneViewLink}
              mainFile={mainFile}
              setMainFile={setMainFile}
            />
          );
        default:
          return null;
      }
    }
  };

  return (
    <div className="fixed inset-0 z-50 flex items-start justify-center overflow-y-auto overflow-x-hidden bg-black bg-opacity-50 p-3 sm:p-4">
      <div className="relative mt-8 flex w-full max-w-5xl gap-6 sm:mt-10 md:mt-20">
        {/* Left Sidebar for Desktop */}
        <div className="hidden w-56 rounded-lg bg-gray-100 p-4 md:block md:p-6">
          <div className="space-y-4">
            {steps.map((step) => (
              <div key={step.number} className="flex flex-col">
                <div className="flex items-center gap-3">
                  <div 
                    className={`h-4 w-4 rounded-full ${
                      activeStep >= step.number ? 'bg-purple-600' : 'bg-gray-300'
                    }`} 
                  />
                  <span className="font-medium">{step.title}</span>
                </div>
                <div className="ml-[7px] mt-1 border-l border-gray-300 pl-4 text-sm text-gray-500">
                  Step {step.number}
                </div>
              </div>
            ))}
          </div>
        </div>

        {/* Progress indicator for Mobile */}
        <div className="fixed left-0 right-0 top-0 z-50 bg-white p-4 shadow-md md:hidden">
          <div className="flex items-center justify-between">
            <span className="text-sm font-medium">Step {activeStep} of {steps.length}</span>
            <div className="mx-4 flex h-2 flex-1 overflow-hidden rounded-full bg-gray-200">
              <div
                className="bg-purple-600 transition-all duration-300 ease-in-out"
                style={{ width: `${(activeStep / steps.length) * 100}%` }}
              />
            </div>
            <button 
              onClick={onClose} 
              className="text-gray-500 hover:text-gray-700"
              disabled={isSubmitting}
            >
              <X size={20} />
            </button>
          </div>
        </div>

        {/* Main Content */}
        <div className="relative w-full rounded-lg bg-white p-4 shadow-xl sm:p-6 md:p-8">
          <button 
            onClick={onClose} 
            className="absolute right-4 top-4 text-gray-500 hover:text-gray-700"
            disabled={isSubmitting}
          >
            <X size={24} />
          </button>

          <div className="mb-6 mt-12 sm:mb-8 md:mt-0">
            {renderStepContent()}
          </div>

          {error && (
            <div className="mb-4 rounded-lg bg-red-50 p-4 text-sm text-red-600">
              {error}
            </div>
          )}

          <div className="flex items-center justify-end gap-3 sm:gap-4">
            {activeStep > 1 && (
              <button
                onClick={handlePrevious}
                className="flex items-center gap-2 rounded-lg border border-gray-300 px-4 py-2 text-sm font-medium text-gray-700 hover:bg-gray-50 sm:px-6 sm:py-2.5"
                disabled={isSubmitting}
              >
                <ArrowLeft size={16} />
                Previous
              </button>
            )}
            <button
              onClick={activeStep === steps.length ? handlePostAsAdmin : handleNext}
              className="flex items-center gap-2 rounded-lg bg-purple-600 px-4 py-2 text-sm font-medium text-white hover:bg-opacity-90 sm:px-6 sm:py-2.5"
              disabled={isSubmitting}
            >
              {activeStep === steps.length ? (
                isSubmitting ? 'Posting...' : 'Post For Verification'
              ) : (
                <>
                  Next
                  <ArrowRight size={16} />
                </>
              )}
            </button>
          </div>

          {/* Display Submitted Data */}
          {submittedData && (
            <div className="mt-8 rounded-lg bg-gray-50 p-4 sm:p-6">
              <h3 className="text-lg font-medium">Submitted Property Data:</h3>
              <pre className="mt-4 overflow-x-auto rounded-lg bg-gray-100 p-4 text-sm text-gray-700">
                {JSON.stringify(submittedData, null, 2)}
              </pre>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default PropertyWizardModal;